@@ -483,7 +483,7 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin):
         return module
 
     @cached_property
-    def filepath(self) -> Path:
+    def filepath(self) -> Path | list[Path]:
         """Return the file path where this object was defined.
 
         It should never return None for non-module objects,
@@ -492,18 +492,38 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin):
         If it _does_ return None, it means the tree was not built correctly.
 
         Returns:
-            A file path.
+            A file path or a list of directories.
         """
         return self.module.filepath
 
-    @cached_property
-    def relative_filepath(self) -> Path:
+    @cached_property  # noqa: WPS231
+    def relative_filepath(self) -> Path:  # noqa: WPS231
         """Return the file path where this object was defined, relative to the top module path.
 
+        Raises:
+            ValueError: When the relative path could not be computed.
+
         Returns:
             A file path.
         """
-        return self.module.filepath.relative_to(self.package.filepath.parent.parent)
+        package_path = self.package.filepath
+        if isinstance(self.module.filepath, list):
+            if isinstance(package_path, list):
+                for pkg_path in package_path:
+                    for self_path in self.module.filepath:
+                        with suppress(ValueError):
+                            return self_path.relative_to(pkg_path.parent)
+            else:
+                for self_path in self.module.filepath:  # noqa: WPS440
+                    with suppress(ValueError):
+                        return self_path.relative_to(package_path.parent.parent)
+            raise ValueError
+        if isinstance(package_path, list):
+            for pkg_path in package_path:  # noqa: WPS440
+                with suppress(ValueError):
+                    return self.module.filepath.relative_to(pkg_path.parent)
+            raise ValueError
+        return self.module.filepath.relative_to(package_path.parent.parent)
 
     @cached_property
     def path(self) -> str:
@@ -572,6 +592,8 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin):
             filepath = self.filepath
         except BuiltinModuleError:
             return []
+        if isinstance(filepath, list):
+            return []
 
         # TODO: remove once Python 3.7 support is dropped
         if self.lineno and self.endlineno is None and sys.version_info < (3, 8):
@@ -602,7 +624,9 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin):
         Returns:
             The resolved name.
         """
-        if name in self.members and not self.members[name].is_alias:
+        if name in self.members:
+            if self.members[name].is_alias:
+                return self.members[name].target_path  # type: ignore[union-attr]
             return self.members[name].path
         if name in self.imports:
             return self.imports[name]
@@ -652,9 +676,13 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin):
 
     # TODO: remove once Python 3.7 support is dropped
     @property
-    def _endlineno(self) -> int:
+    def _endlineno(self) -> int | None:
         if self.kind is Kind.MODULE:
+            if isinstance(self.filepath, list):
+                return 0
             return len(self.lines_collection[self.filepath])
+        if isinstance(self.filepath, list):
+            return None
         tokens, tokens_by_line = self.lines_collection.tokens(self.filepath)
         first_token_index = tokens_by_line[self.lineno][0]
         blockfinder = inspect.BlockFinder()
@@ -683,6 +711,7 @@ class Alias(ObjectAliasMixin):
         lineno: The alias starting line number.
         endlineno: The alias ending line number.
         parent: The alias parent.
+        target_path: The alias target path.
     """
 
     is_alias: bool = True
@@ -709,10 +738,10 @@ class Alias(ObjectAliasMixin):
         self.name: str = name
         if isinstance(target, str):
             self._target: Object | Alias | None = None
-            self._target_path: str = target
+            self.target_path: str = target
         else:
             self._target = target
-            self._target_path = target.path
+            self.target_path = target.path
             if parent is not None:
                 with suppress(AliasResolutionError):
                     target.aliases[self.path] = self
@@ -724,12 +753,12 @@ class Alias(ObjectAliasMixin):
     def __getattr__(self, name: str) -> Any:
         # forward everything to the target
         if self._passed_through:
-            raise CyclicAliasError([self._target_path])
+            raise CyclicAliasError([self.target_path])
         self._passed_through = True
         try:
             attr = getattr(self.target, name)
         except CyclicAliasError as error:
-            raise CyclicAliasError([self._target_path] + error.chain)
+            raise CyclicAliasError([self.target_path] + error.chain)
         finally:
             self._passed_through = False
         return attr
@@ -810,7 +839,7 @@ class Alias(ObjectAliasMixin):
     @target.setter
     def target(self, value: Object | Alias) -> None:
         if value is self:
-            raise CyclicAliasError([self._target_path])
+            raise CyclicAliasError([self.target_path])
         self._target = value
         if self.parent is not None:
             self._target.aliases[self.path] = self
@@ -827,11 +856,11 @@ class Alias(ObjectAliasMixin):
             CyclicAliasError: When the resolved target is the alias itself.
         """
         try:
-            resolved = self.modules_collection[self._target_path]
+            resolved = self.modules_collection[self.target_path]
         except KeyError as error:
-            raise AliasResolutionError(self._target_path) from error
+            raise AliasResolutionError(self.target_path) from error
         if resolved is self:
-            raise CyclicAliasError([self._target_path])
+            raise CyclicAliasError([self.target_path])
         self._target = resolved
         if self.parent is not None:
             self._target.aliases[self.path] = self  # type: ignore[union-attr]  # we just set the target
@@ -853,7 +882,7 @@ class Alias(ObjectAliasMixin):
             The wildcard imported module, or None.
         """
         if self.name.endswith("/*"):
-            return self._target_path
+            return self.target_path
         return None
 
     def as_dict(self, full: bool = False, **kwargs: Any) -> dict[str, Any]:
@@ -869,7 +898,7 @@ class Alias(ObjectAliasMixin):
         base = {
             "kind": Kind.ALIAS,
             "name": self.name,
-            "target_path": self._target_path,
+            "target_path": self.target_path,
         }
 
         if full:
@@ -888,7 +917,7 @@ class Module(Object):
 
     kind = Kind.MODULE
 
-    def __init__(self, *args: Any, filepath: Path | None = None, **kwargs: Any) -> None:
+    def __init__(self, *args: Any, filepath: Path | list[Path] | None = None, **kwargs: Any) -> None:
         """Initialize the module.
 
         Parameters:
@@ -897,7 +926,7 @@ class Module(Object):
             **kwargs: See [`griffe.dataclasses.Object`][].
         """
         super().__init__(*args, **kwargs)
-        self._filepath: Path | None = filepath
+        self._filepath: Path | list[Path] | None = filepath
 
     def __repr__(self) -> str:
         try:
@@ -906,7 +935,7 @@ class Module(Object):
             return f"<Module({self.name!r})>"
 
     @property
-    def filepath(self) -> Path:
+    def filepath(self) -> Path | list[Path]:
         """Get the file path of this module.
 
         Raises:
@@ -926,6 +955,8 @@ class Module(Object):
         Returns:
             True or False.
         """
+        if isinstance(self.filepath, list):
+            return False
         try:
             return self.filepath.name.split(".", 1)[0] == "__init__"
         except BuiltinModuleError:
@@ -957,7 +988,7 @@ class Module(Object):
             True or False.
         """
         try:
-            return self.parent is None and self.filepath.is_dir()
+            return self.parent is None and isinstance(self.filepath, list)
         except BuiltinModuleError:
             return False
 
@@ -971,7 +1002,7 @@ class Module(Object):
         try:
             return (
                 self.parent is not None
-                and self.filepath.is_dir()
+                and isinstance(self.filepath, list)
                 and (
                     cast(Module, self.parent).is_namespace_package or cast(Module, self.parent).is_namespace_subpackage
                 )
