@@ -21,3 +21,17 @@ def test_annotations_from_classes():
         assert func.parameters[0].name == "a"
         assert func.parameters[0].annotation == Name("A", full=f"{module.name}.A")
         assert func.returns == Name("A", full=f"{module.name}.A")
+
+
+def test_class_level_imports():
+    """Assert annotations using class-level imports are resolved."""
+    with temporary_inspected_module(
+        """
+        class A:
+            from io import StringIO
+            def method(self, p: StringIO):
+                pass
+        """
+    ) as module:
+        method = module["A.method"]
+        assert method.parameters["p"].annotation == Name("StringIO", full="io.StringIO")
